==> banshee_1.0.0.orig.tar.gz: banshee-1-1.0.0/src/Core/Banshee.Services/Banshee.Library/HomeDirectoryImportSource.cs <==
//
// HomeDirectoryImportSource.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2006-2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using Mono.Unix;

namespace Banshee.Library
{
    public class HomeDirectoryImportSource : IImportSource
    {
        public HomeDirectoryImportSource ()
        {
        }

        public void Import ()
        {
            Banshee.ServiceStack.ServiceManager.Get<LibraryImportManager> ().QueueSource (
                Environment.GetFolderPath (Environment.SpecialFolder.Personal)
            );
        }
        
        public string Name {
            get { return Catalog.GetString ("Home Directory"); }
        }
        
        public string [] IconNames {
            get { return new string [] { "user-home", "gtk-home" }; }
        }
        
        public bool CanImport {
            get { return true; }
        }
    }
}

==> banshee-1-1.9.0.tar.gz: banshee-1-1.9.0/src/Core/Banshee.Services/Banshee.Library/HomeDirectoryImportSource.cs <==
//
// HomeDirectoryImportSource.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2006-2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using Mono.Unix;

namespace Banshee.Library
{
    public class HomeDirectoryImportSource : IImportSource
    {
        public HomeDirectoryImportSource ()
        {
        }

        public void Import ()
        {
            Banshee.ServiceStack.ServiceManager.Get<LibraryImportManager> ().Enqueue (
                Environment.GetFolderPath (Environment.SpecialFolder.Personal)
            );
        }

        public string Name {
            get { return Catalog.GetString ("Home Folder"); }
        }

        public string ImportLabel { get { return null; } }

        public string [] IconNames {
            get { return new string [] { "user-home", "gtk-home" }; }
        }

        public bool CanImport {
            get { return true; }
        }

        public int SortOrder {
            get { return 12; }
        }
    }
}
